==> GO_1.16.0.tar.gz: GO/man/GOCCOFFSPRING.Rd <==
\name{GOCCOFFSPRING}
\alias{GOCCOFFSPRING}
\title{Annotation of GO Identifiers to their Cellular Component Offspring} 
\description{
This is an R environment (hash table) mapping GO identifiers to all the GO
identifiers of their offspring based on the  cellular component (CC) GO terms. Offspring are
defined as the direct or indirect children/grand children nodes of a
given node for a GO identifier based on the directed acyclic graph defined by
Gene Ontology Consortium. GO terms for offspring nodes are more specific
than that of the parent.
}
\details{
  GO identifiers are keys and the corresponding offspring GO identifiers are
  values. Values are vectors of GO identifiers for all the offspring of the key
  GO identifier. GO identifiers that do not have any offspring node are assigned NA as
  the value. 

  Cellular component is defined as the subcellular structures,
  locations, and macromolecular complexes; examples include nucleus,
  telomere, and origin recognition complex as defined b y Gene Ontology
  Consortium. 
  
  Mappings were based on data provided:

  Gene Ontology:\\url{http://gopher5/compbio/annotationSourceData/archive.godatabase.org/latest/}. Built: 08-Feb-2007
 
  Package built: Fri Mar  2 13:37:12 2007
}
\references{
\url{http://www.geneontology.org/} and
\url{http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?db=gene} 
}
\examples{
  require("GO", character.only = TRUE) || stop("GO unavailable")
  # Convert the environment object to a list
  xx <- as.list(GOCCOFFSPRING)
  # Remove GO identifiers that do not have any offspring
  xx <- xx[!is.na(xx)]
  if(length(xx) > 0){
    # Get the offspring GO identifiers for the first two elents of xx
    goidentifiers <- xx[1:2]
  }
}
\keyword{datasets}

==> GO_2.0.1.tar.gz: GO/man/GOCCOFFSPRING.Rd <==
\name{GOCCOFFSPRING}
\alias{GOCCOFFSPRING}
\title{Annotation of GO Identifiers to their Cellular Component Offspring} 
\description{
This is an R environment (hash table) mapping GO identifiers to all the GO
identifiers of their offspring based on the  cellular component (CC) GO terms. Offspring are
defined as the direct or indirect children/grand children nodes of a
given node for a GO identifier based on the directed acyclic graph defined by
Gene Ontology Consortium. GO terms for offspring nodes are more specific
than that of the parent.
}
\details{
  GO identifiers are keys and the corresponding offspring GO identifiers are
  values. Values are vectors of GO identifiers for all the offspring of the key
  GO identifier. GO identifiers that do not have any offspring node are assigned NA as
  the value. 

  Cellular component is defined as the subcellular structures,
  locations, and macromolecular complexes; examples include nucleus,
  telomere, and origin recognition complex as defined b y Gene Ontology
  Consortium. 
  
  Mappings were based on data provided:

  Gene Ontology:\\url{ftp://ftp.geneontology.org/pub/go/godatabase/archive/latest}. Built: Build Information not available
 
  Package built: Wed Aug 29 09:09:17 2007
}
\references{
\url{http://www.geneontology.org/} and
\url{http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?db=gene} 
}
\examples{
  require("GO", character.only = TRUE) || stop("GO unavailable")
  # Convert the environment object to a list
  xx <- as.list(GOCCOFFSPRING)
  # Remove GO identifiers that do not have any offspring
  xx <- xx[!is.na(xx)]
  if(length(xx) > 0){
    # Get the offspring GO identifiers for the first two elents of xx
    goidentifiers <- xx[1:2]
  }
}
\keyword{datasets}
